%Szablon pracy dyplomowej poprawiony i zmodyfikowany na potrzeby wydziału Elektroniki, Mikrosystemów i Fotoniki Politechniki Wrocławskiej
%przez dr inż. Mariusza Ostrowskigego <mariusz.ostrowski@pwr.edu.pl> na podstawie szablonu https://github.com/rkubosz/dyplompwr udostępnionego na licencji MIT.

%plik dyplompwr.cls wystarczy umieścić w katalogu zawierającym plik główny pracy .tex

\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{dyplompwr}

% Inicjalizacja opcji
\newif\if@archive
\newif\if@oneside
\newif\if@engineer
\newif\if@master
\newif\if@eng
\newif\if@pl
\newif\if@old

\@mastertrue
\@archivetrue
\@pltrue
\DeclareOption{archive}{\@archivetrue\@onesidefalse}
\DeclareOption{oneside}{\@onesidetrue\@archivefalse}
\DeclareOption{engineer}{\@engineertrue\@masterfalse}
\DeclareOption{master}{\@mastertrue\@engineerfalse}
\DeclareOption{enold}{\@engtrue\@plfalse}
\DeclareOption{en}{\@engtrue\@plfalse}
\DeclareOption{pl}{\@pltrue\@engfalse}
\DeclareOption{oldtitlepage}{\@oldtrue}
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{mwrep}}
\ProcessOptions

% Wczytywanie klasy bazowej -- mwrep -- wraz z odpowiednią interlinią i marginesami
\if@archive
	\LoadClass[12pt,openany,twoside]{mwrep}
	\RequirePackage[a4paper,outer=2cm,inner=3.5cm,top=2.5cm,bottom=2.5cm]{geometry}
% Interlinia jest ustawiana na 1
	\RequirePackage[singlespacing]{setspace}
\fi

\if@oneside
	\LoadClass[12pt]{mwrep}
	\RequirePackage[a4paper,top=2.5cm,left=3.5cm,right=2.5cm,bottom=2.5cm]{geometry}
% Zmieniamy interlinię na 1.5 dla poprawienia przejrzystości
	\RequirePackage[onehalfspacing]{setspace}
\fi

%%		Wymagane pakiety
\RequirePackage{graphicx}

\RequirePackage[ddmmyyyy]{datetime}
% standardowy font, ładowany dla pewności
\RequirePackage{lmodern}
% to na potrzeby strony tytułowej
\RequirePackage{xcolor}
\def\ifundefined#1{\expandafter\ifx\csname#1\endcsname\relax}

%%		Opcje językowe na potrzeby strony tytułowej
\if@pl
	\def\xd{Promotor: }
	\if@master
		\def\thesisheader{Praca Dyplomowa \\ Magisterska}
	\fi
	\if@engineer
		\def\thesisheader{Praca Dyplomowa \\ In\.{z}ynierska}
	\fi

\fi

\if@eng
	\def\xd{Supervisor: }
	\if@master
		\def\thesisheader{Master Thesis}
	\fi
	\if@engineer
		\def\thesisheader{Bachelor Thesis}
	\fi

\fi

%%		Strona tytułowa
\def\supervisor#1{\gdef\@supervisor{#1}}
\def\consultant#1{\gdef\@consultant{#1}}
\def\city#1{\gdef\@city{#1}}
\def\year#1{\gdef\@year{#1}}
\def\dedication#1{\gdef\@dedication{#1}}
\def\@supervisor{\@latex@error{No \noexpand\supervisor given}\@ehc}
\def\fieldofstudy#1{\gdef\@fieldofstudy{#1}}
\def\faculty#1{\gdef\@faculty{#1}}
\def\keywords#1{\gdef\@keywords{#1}}
\def\@keywords{\@latex@error{No \noexpand\keywords given}\@ehc}
\def\abstract#1{\gdef\@abstract{#1}}
\def\@abstract{\@latex@error{No \noexpand\abstract given}\@ehc}
\def\titlen#1{\gdef\@titlen{#1}}
\def\@titlen{\@latex@error{No \noexpand\titlen given}\@ehc}

\consultant{}

\if@pl
	\RequirePackage{polski}
	\renewcommand{\figurename}{Rys.}
	\renewcommand{\tablename}{Tab.}
\fi
\if@eng
	\renewcommand{\figurename}{Fig.}
	\renewcommand{\tablename}{Tab.}
\fi

\renewcommand{\paragraph}{\@startsection{paragraph}{4}{0ex}
   {-3.25ex plus -1ex minus -0.2ex}
   {1.5ex plus 0.2ex}
   {\normalfont\normalsize\itshape}}


\renewcommand\maketitle{


	\begin{titlepage}
		% marginesy strony tytułowej
		\newgeometry{left=25mm,right=25mm,top=25mm,bottom=25mm}
		\pagenumbering{alph}
		\noindent\unitlength1mm

		% tutaj się zaczyna rozmiejscawianie elementów strony tytułowej. Zaczynamy
		% od loga PWr i nazwy wydziału
		\begin{picture}(0,0)


			\if@old
				\if@pl
					\put(75,0){
						\makebox(0,0)[cb]{
					\fontsize{26pt}{26pt}\usefont{T1}{ptm}{m}{n}{Politechnika Wroc\l{}awska}}}
					\put(75,-20){
						\makebox(0,0)[cb]{
					\fontsize{19pt}{19pt}\usefont{T1}{ptm}{m}{n}{\@faculty}}}
					\put(0,-30){\rule{160mm}{.1mm}}
				\fi
				\if@eng
					\put(75,0){
						\makebox(0,0)[cb]{
							\fontsize{26pt}{26pt}\usefont{T1}{ptm}{m}{n}{Wroc\l{}aw University of Science and}}}
					\put(75,-10){
						\makebox(0,0)[cb]{
							\fontsize{26pt}{26pt}\usefont{T1}{ptm}{m}{n}{Technology}}}
					\put(75,-20){
						\makebox(0,0)[cb]{
					\fontsize{20pt}{20pt}\usefont{T1}{ptm}{m}{n}{\@faculty}}}
					\put(0,-30){\rule{160mm}{.1mm}}
				\fi
				\if@pl
					\put(75,-55){
						\makebox(0,0)[cb]{
					\fontsize{20pt}{20pt}\usefont{T1}{ptm}{m}{n}{Kierunek:}}}
					\put(75,-65){
						\makebox(0,0)[cb]{
					\fontsize{16pt}{16pt}\usefont{T1}{ptm}{m}{n}{\@fieldofstudy}}}

				\fi
				\if@eng
					\put(75,-55){\makebox(0,0)[cb]{
						\fontsize{20pt}{20pt}\usefont{T1}{ptm}{m}{n}{Field of study:}}}
					\put(75,-65){\makebox(0,0)[t]{\parbox{160mm}{
						\onehalfspacing\centering\fontsize{16pt}{16pt}\usefont{T1}{ptm}{m}{n}{\@fieldofstudy}}}}
				\fi

				\put(75,-83){\makebox(0,0)[t]{\parbox{160mm}{
				\onehalfspacing\centering\fontsize{26pt}{26pt}\usefont{T1}{ptm}{m}{n}\thesisheader}}}


				\put(75,-117){\makebox(0,0)[t]{\parbox{160mm}{
				\onehalfspacing\centering\fontsize{20pt}{20pt}\usefont{T1}{ptm}{m}{n}\if@pl Tytu\l{} pracy: \fi\if@eng Title of Thesis: \fi \\ \@title}}}

				\put(75,-140){\makebox(0,0)[t]{\parbox{160mm}{\onehalfspacing
				\centering\fontsize{20pt}{20pt}\usefont{T1}{ptm}{m}{n}\if@pl Autor: \fi\if@eng Author: \fi}}}
				\put(75,-160){\makebox(0,0)[t]{\parbox{160mm}{\onehalfspacing
				\centering\fontsize{16pt}{16pt}\usefont{T1}{ptm}{m}{n}\@author}}}

				\put(75,-184){\makebox(0,0)[t]{\parbox{160mm}{\onehalfspacing
				\centering\fontsize{20pt}{20pt}\usefont{T1}{ptm}{m}{n}\if@pl Promotor: \fi\if@eng Supervisor: \fi}}}
				\put(75,-207){\makebox(0,0)[t]{\parbox{160mm}{\onehalfspacing
				\centering\fontsize{16pt}{16pt}\usefont{T1}{ptm}{m}{n}\@supervisor}}}

				\put(0,-228){\rule{160mm}{.1mm}}

				\put(75,-241){\makebox(0,0){\fontsize{20pt}{20pt}\usefont{T1}{ptm}{m}{n}{ \@city \ \@year }}}

			\else
				\if@pl
					\put(75,0){
						\makebox(0,0)[cb]{
					\fontsize{27pt}{27pt}\usefont{T1}{ptm}{m}{n}{Politechnika Wroc\l{}awska}}}
					\put(75,-8){
						\makebox(0,0)[cb]{
					\fontsize{18pt}{18pt}\usefont{T1}{ptm}{m}{n}{\@faculty}}}
				\fi
				\if@eng
					\put(72,0){
						\makebox(0,0)[cb]{
					\fontsize{25pt}{25pt}\usefont{T1}{ptm}{m}{n}{Wroc\l{}aw University of Science and Technology}}}
					\put(75,-8){
						\makebox(0,0)[cb]{
					\fontsize{18pt}{18pt}\usefont{T1}{ptm}{m}{n}{\@faculty}}}
				\fi

				\put(-10,-10){\rule{170mm}{.1mm}}

				\if@pl
					\put(-12,-21){
						\makebox(0,0)[l]{
					\fontsize{16pt}{16pt}\usefont{T1}{ptm}{m}{n}{\textsc{Kierunek:} \@fieldofstudy}}}
				\fi
				\if@eng
					\put(-12,-21){
						\makebox(0,0)[l]{
					\fontsize{14pt}{14pt}\usefont{T1}{ptm}{m}{n}{\textsc{Field of study:} \@fieldofstudy}}}
				\fi

				\put(70,-38){
					\makebox(0,0)[t]{\parbox{160mm}{
						\onehalfspacing\centering\fontsize{28pt}{28pt}\usefont{T1}{ptm}{m}{n}\textsc{ \thesisheader}}}}


				\put(51,-80){\makebox(0,0)[l]{\parbox{106mm}{
				\onehalfspacing\centering\fontsize{16pt}{16pt}\usefont{T1}{ptm}{m}{n}\if@pl Tytu\l{} pracy: \fi\if@eng Title of Thesis: \fi \\ \@title}}}

				\put(51,-106){\makebox(0,0)[l]{\parbox{106mm}{\onehalfspacing
				\centering\fontsize{18pt}{18pt}\usefont{T1}{ptm}{m}{n}\if@pl \textsc{Autor:} \fi\if@eng \textsc{Author:} \fi}}}
				\put(51,-114){\makebox(0,0)[l]{\parbox{106mm}{\onehalfspacing
				\centering\fontsize{14pt}{14pt}\usefont{T1}{ptm}{m}{n}\@author}}}

				\put(80,-173){\makebox(0,0)[l]{\parbox{80mm}{\onehalfspacing
				\fontsize{20pt}{20pt}\usefont{T1}{ptm}{m}{n}\if@pl \textsc{Promotor:} \fi\if@eng \textsc{Supervisor:} \fi}}}
				\put(80,-181){\makebox(0,0)[l]{\parbox{80mm}{\onehalfspacing
				\fontsize{14pt}{14pt}\usefont{T1}{ptm}{m}{n}\@supervisor}}}

				\ifx \@consultant \@empty \else
					\put(80,-208){\makebox(0,0)[l]{\parbox{80mm}{\onehalfspacing
					\fontsize{16pt}{16pt}\usefont{T1}{ptm}{m}{n}\if@pl \textsc{Konsultant:} \fi\if@eng \textsc{Consultant:} \fi}}}
					\put(80,-215){\makebox(0,0)[l]{\parbox{80mm}{\onehalfspacing
					\fontsize{14pt}{14pt}\usefont{T1}{ptm}{m}{n}\@consultant}}}
				\fi


				\put(-10,-242){\rule{170mm}{.1mm}}

				\put(75,-246){\makebox(0,0){\fontsize{16pt}{16pt}\usefont{T1}{ptm}{m}{n}{\textsc{ \@city \ \@year} }}}
			\fi
		\end{picture}

		\let\footnotesize\small
		\let\footnoterule\relax
		\let\footnote\thanks
		\mbox{}
		\cleardoublepage
	\end{titlepage}

	\restoregeometry
	\setcounter{footnote}{0}
	\global\let\thanks\relax
	\global\let\maketitle\relax
	\global\let\@thanks\@empty
	\global\let\@author\@empty
	\global\let\@date\@empty
	\global\let\@title\@empty
	\global\let\@titlen\@empty
	\global\let\@faculty\@empty
	\global\let\@abstract\@empty
	\global\let\@keywords\@empty
	\global\let\@supervisor\@empty
	\global\let\title\relax
	\global\let\titlen\relax
	\global\let\author\relax
	\global\let\date\relax
	\global\let\and\relax
	\global\let\abstract\relax
	\global\let\faculty\relax
	\global\let\keywords\relax
	\global\let\supervisor\relax
	\pagenumbering{arabic}
}
%wymuszenie ukrywania rozdziałów w spisie treści
\renewcommand*\chapter@toc{%
  \ifHeadingNumbered\typeout{\@chapapp\space\thechapter.}
  \addcontentsline{toc}{chapter}{%
        \ifHeadingNumbered
 \protect\numberline{\mw@seccntformat{\HeadingNumber}}%
        \fi
            \HeadingTOCText}\fi%
  \addtocontents{lof}{\protect\addvspace{10\p@}}%
  \addtocontents{lot}{\protect\addvspace{10\p@}}%
  }
%

% Wymusza jednopoziomowe numerowanie tabel rysunków i wzorów.
% W przypadku chęci powrotu do domyślengo wielopoziomowego numerowania usunąć poniższe linie.
\newcommand{\oneLevelNumbering}{
	\usepackage{chngcntr}
	\counterwithout{figure}{chapter}
	\counterwithout{table}{chapter}
	\counterwithout{equation}{chapter}
}
%

% wymuszenie numeru strony po prawej
\newcommand{\pageNumberOnTheRight}{
	\RequirePackage{fancyhdr}
	\pagestyle{fancy}
	\if@oneside
		\fancyhf{}\fancyfoot[R]{\thepage}

		\fancypagestyle{opening}{\fancyhf{}\fancyfoot[R]{\thepage}
			\renewcommand{\headrulewidth}{0pt}
			\renewcommand{\footrulewidth}{0pt}}
		\fancypagestyle{closing}{\fancyhf{}\fancyfoot[R]{\thepage}%
			\renewcommand{\headrulewidth}{0pt}
			\renewcommand{\footrulewidth}{0pt}}
	\else
		\fancyhf{}\fancyfoot[RO,LE]{\thepage}

		\fancypagestyle{opening}{\fancyhf{}\fancyfoot[RO,LE]{\thepage}
			\renewcommand{\headrulewidth}{0pt}
			\renewcommand{\footrulewidth}{0pt}}
		\fancypagestyle{closing}{\fancyhf{}\fancyfoot[RO,LE]{\thepage}%
			\renewcommand{\headrulewidth}{0pt}
			\renewcommand{\footrulewidth}{0pt}}
	\fi
}

\endinput
